==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/Projects.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) Programmatic API for projen.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.433Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.Projects")
public class Projects extends software.amazon.jsii.JsiiObject {

    protected Projects(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Projects(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * (experimental) Creates a new project with defaults.
     * <p>
     * This function creates the project type in-process (with in VM) and calls
     * <code>.synth()</code> on it (if <code>options.synth</code> is not <code>false</code>).
     * <p>
     * At the moment, it also generates a <code>.projenrc.js</code> file with the same code
     * that was just executed. In the future, this will also be done by the project
     * type, so we can easily support multiple languages of projenrc.
     * <p>
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static void createProject(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.CreateProjectOptions options) {
        software.amazon.jsii.JsiiObject.jsiiStaticCall(io.github.cdklabs.projen.Projects.class, "createProject", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(options, "options is required") });
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/Projects.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) Programmatic API for projen.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.140Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.Projects")
public class Projects extends software.amazon.jsii.JsiiObject {

    protected Projects(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Projects(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * (experimental) Creates a new project with defaults.
     * <p>
     * This function creates the project type in-process (with in VM) and calls
     * <code>.synth()</code> on it (if <code>options.synth</code> is not <code>false</code>).
     * <p>
     * At the moment, it also generates a <code>.projenrc.js</code> file with the same code
     * that was just executed. In the future, this will also be done by the project
     * type, so we can easily support multiple languages of projenrc.
     * <p>
     * An environment variable (PROJEN_CREATE_PROJECT=true) is set within the VM
     * so that custom project types can detect whether the current synthesis is the
     * result of a new project creation (and take additional steps accordingly)
     * <p>
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static void createProject(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.CreateProjectOptions options) {
        software.amazon.jsii.JsiiObject.jsiiStaticCall(io.github.cdklabs.projen.Projects.class, "createProject", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(options, "options is required") });
    }
}
